BanzaiDB tables schema — BanzaiDB 0.1.1 documentation

### Navigation

- index
- modules |
- BanzaiDB 0.1.1 documentation »

# BanzaiDB tables schema

The following tables are defined in BanzaiDB

## Mapping

reference_genome_features strains_under_investigation reference_genomes

### determined_variants

Key | Value (type) | Comments
--- | --- | ---
id | string | Primary (StrainID_RefID_Position)
StrainID | string |
Positiion | int |
LocusTag | string | Of reference
Class | string | substitution, insertion, deletion
SubClass | string or None | synonymous, non-synonymous
RefBase | char | A T C or G (N) ?
ChangeBase | char | A T C G or (N) ?
CDSBaseNum | int |
CDSAANum | int |
CDSRegion | string or None | x..y
RefAA | char or None |
ChangeAA | char of None |
Product | string |
CorrelatedChange | boolean | If up/down-stream change effects
Evidence | string |

### strains_under_investigation

Key | Value (type) | Comments
--- | --- | ---
StrainID | string |
VarCount | int | total number of parsed (CDS) variants

## REF

## REF_FEATURES

Key | Value (type) | Comments
--- | --- | ---
LocusTag | string |
Sequence | int |
Translation | string |
Start | int |
End | int |
Strand | int | 1/-1
Product | string | Should be equal to VARIANT[‘CDS’]

### Navigation

- index
- modules |
- BanzaiDB 0.1.1 documentation »